@@ -4,7 +4,6 @@ use crate::{
 };
 use odbc_sys::{Date, Time, Timestamp, NULL_DATA};
 use std::{
-    convert::TryInto,
     ffi::c_void,
     mem::size_of,
     ptr::{null, null_mut},
@@ -69,10 +68,15 @@ where
             values: &mut self.values[0..n],
         }
     }
+
+    /// Maximum number elements which the column may hold.
+    pub fn capacity(&self) -> usize {
+        self.indicators.len()
+    }
 }
 
 /// Iterates over the elements of a column buffer. Returned by
-/// [`crate::buffers::ColumnarRowSet::column`] as part of an [`crate::buffers::AnyColumnView`].
+/// [`crate::buffers::ColumnarBuffer::column`] as part of an [`crate::buffers::AnyColumnView`].
 #[derive(Debug)]
 pub struct NullableSlice<'a, T> {
     indicators: &'a [isize],
@@ -178,7 +182,7 @@ where
     }
 }
 
-/// Used to fill a column buffer with an iterator. Returned by [`super::ColumnarRowSet::column_mut`]
+/// Used to fill a column buffer with an iterator. Returned by [`super::ColumnarBuffer::column_mut`]
 /// as part of an [`crate::buffers::AnyColumnViewMut`].
 #[derive(Debug)]
 pub struct NullableSliceMut<'a, T> {
