@@ -1,6 +1,7 @@
 use std::{cmp::max, collections::HashMap, ptr::null_mut, sync::Mutex};
 
 use crate::{
+    error::ExtendResult,
     handles::{self, log_diagnostics, OutputStringBuffer, SqlResult, SqlText, State, SzBuffer},
     Connection, DriverCompleteOption, Error,
 };
@@ -11,10 +12,10 @@ use odbc_sys::{AttrCpMatch, AttrOdbcVersion, FetchOrientation, HWnd};
 // Currently only windows driver manager supports prompt.
 use winit::{event_loop::EventLoop, platform::windows::WindowExtWindows, window::WindowBuilder};
 
-#[cfg(not(feature="odbc_version_3_5"))]
+#[cfg(not(feature = "odbc_version_3_5"))]
 const ODBC_API_VERSION: AttrOdbcVersion = AttrOdbcVersion::Odbc3_80;
 
-#[cfg(feature="odbc_version_3_5")]
+#[cfg(feature = "odbc_version_3_5")]
 const ODBC_API_VERSION: AttrOdbcVersion = AttrOdbcVersion::Odbc3;
 
 /// An ODBC 3.8 environment.
@@ -151,15 +152,11 @@ impl Environment {
 
         // Translate invalid attribute into a more meaningful error, provided the additional
         // context that we know we tried to set version number.
-        result.map_err(|error| {
-            if let Error::Diagnostics { record, function } = error {
-                if record.state == State::INVALID_STATE_TRANSACTION {
-                    Error::UnsupportedOdbcApiVersion(record)
-                } else {
-                    Error::Diagnostics { record, function }
-                }
+        result.provide_context_for_diagnostic(|record, function| {
+            if record.state == State::INVALID_STATE_TRANSACTION {
+                Error::UnsupportedOdbcApiVersion(record)
             } else {
-                error
+                Error::Diagnostics { record, function }
             }
         })?;
 
