@@ -1,8 +1,6 @@
-use widestring::{U16Str, U16String};
-
 use crate::{
     execute::{execute_columns, execute_tables, execute_with_parameters},
-    handles::StatementImpl,
+    handles::{SqlText, StatementImpl},
     CursorImpl, Error, ParameterRefCollection,
 };
 
@@ -41,15 +39,6 @@ impl<'o> Preallocated<'o> {
         Self { statement }
     }
 
-    /// Executes an sql statement using a wide string. See [`Self::execute`].
-    pub fn execute_utf16(
-        &mut self,
-        query: &U16Str,
-        params: impl ParameterRefCollection,
-    ) -> Result<Option<CursorImpl<&mut StatementImpl<'o>>>, Error> {
-        execute_with_parameters(move || Ok(&mut self.statement), Some(query), params)
-    }
-
     /// Executes a statement. This is the fastest way to sequentially execute different SQL
     /// Statements.
     ///
@@ -95,8 +84,8 @@ impl<'o> Preallocated<'o> {
         query: &str,
         params: impl ParameterRefCollection,
     ) -> Result<Option<CursorImpl<&mut StatementImpl<'o>>>, Error> {
-        let query = U16String::from_str(query);
-        self.execute_utf16(&query, params)
+        let query = SqlText::new(query);
+        execute_with_parameters(move || Ok(&mut self.statement), Some(&query), params)
     }
 
     /// Transfer ownership to the underlying statement handle.
@@ -126,17 +115,17 @@ impl<'o> Preallocated<'o> {
     ///   all.
     pub fn tables(
         &mut self,
-        catalog_name: Option<&str>,
-        schema_name: Option<&str>,
-        table_name: Option<&str>,
-        table_type: Option<&str>,
+        catalog_name: &str,
+        schema_name: &str,
+        table_name: &str,
+        table_type: &str,
     ) -> Result<CursorImpl<&mut StatementImpl<'o>>, Error> {
         execute_tables(
             &mut self.statement,
-            catalog_name.map(U16String::from_str).as_deref(),
-            schema_name.map(U16String::from_str).as_deref(),
-            table_name.map(U16String::from_str).as_deref(),
-            table_type.map(U16String::from_str).as_deref(),
+            &SqlText::new(catalog_name),
+            &SqlText::new(schema_name),
+            &SqlText::new(table_name),
+            &SqlText::new(table_type),
         )
     }
 
@@ -158,10 +147,10 @@ impl<'o> Preallocated<'o> {
     ) -> Result<CursorImpl<&mut StatementImpl<'o>>, Error> {
         execute_columns(
             &mut self.statement,
-            &U16String::from_str(catalog_name),
-            &U16String::from_str(schema_name),
-            &U16String::from_str(table_name),
-            &U16String::from_str(column_name),
+            &SqlText::new(catalog_name),
+            &SqlText::new(schema_name),
+            &SqlText::new(table_name),
+            &SqlText::new(column_name),
         )
     }
 }
